import { notFound } from 'next/navigation';
import BlogPostClient from './BlogPostClient';
import { API_BASE_URL } from '@/app/utils/apiConfig';
import { endpoints } from '@/app/utils/endpoints';

type BlogPostPageProps = {
  params: Promise<{
    slug: string;
  }>;
};

async function getPost(slug: string) {
  try {
    const res = await fetch(`${API_BASE_URL}${endpoints.blog.single(slug)}`, {
      cache: 'no-store',
    });

    if (!res.ok) return null;

    return await res.json();
  } catch (error) {
    return null;
  }
}

export default async function BlogPostPage({ params }: BlogPostPageProps) {
  const { slug } = await params; // Await params before accessing properties
  const post = await getPost(slug);

  if (!post) return notFound();

  return <BlogPostClient post={post} />;
}